import requests
import configparser
import os

class Client:
    def __init__(self):
        path_current_directory = os.path.dirname(__file__)
        config_path = os.path.join(path_current_directory, 'config', 'config.ini')
        config = configparser.ConfigParser()
        config.read(config_path)
        self.config = config

    def getPortfolio(self,userId):
        url = "{}/getPortfolioStocks".format(self.config['common']['api'])
        data = {"userId":"{}".format(userId)}
        res = requests.post(url,data=data)
        portfolio = res.json()
        return portfolio['data']['ticker_ids']
        

    def getWatchlist(self, userId):
        url = "{}/getWatchListStocks".format(self.config['common']['api'])
        data = {"userId":"{}".format(userId)}
        res = requests.post(url,data=data)
        portfolio = res.json()
        return portfolio['data']['ticker_ids']

    def getAlertlist(self,userId):
        url = "{}/getAlertListStocks".format(self.config['common']['api'])
        data = {"userId":"{}".format(userId)}
        res = requests.post(url,data=data)
        portfolio = res.json()
        return portfolio['data']['ticker_ids']

userId = "ECe46JzLI1639136594141"
cs = Client()
print(cs.getPortfolio(userId))
print(cs.getWatchlist(userId))
print(cs.getWatchlist(userId))


import requests
import json
from flask import Flask, jsonify, request
import asyncio
from sendMessage import SendMessage


app = Flask(__name__)

@app.route("/python-package", methods=["POST"])
def GetMessage():
    try:
        message_dict = json.loads(request.get_json())
        print(message_dict)
        notification = message_dict['notification']
        room_id = message_dict['room_id']
        asyncio.run(SendMessage(notification, room_id))
        return ("SuccessResponse")
    except Exception as e:
        print(e)

if __name__ == "__main__":
    app.run(debug=True,host='0.0.0.0', port=5001)


import asyncio
from email import message
from nio import AsyncClient

async def SendMessage(message, roomid):
    try:
        userid = 'gsanas'
        password = 'Woyce@123'
        client = AsyncClient("https://stockly.ems.host", userid)
        await client.login(password)
        await client.room_send(
            room_id=roomid,
            message_type="m.room.message",
            content={
                "msgtype": "m.text",
                "body": "{}".format(message)
            }
        )
        await client.close()
    except Exception as e:
        print(e)

# roomId = "!cAMpKSOoWRZmBPetkc:stockly.ems.host"
# asyncio.run(SendMessage('Hello', roomId))



import json
from datetime import datetime
class messageEmbed:
    def setColor(self, color):
        self.data['color'] = color
        self.color = color
        return self.data

    def setTitle(self, title):
        self.data['title'] = title
        self.title = title
        return self.data
  
    def setURL(self, url):
        self.data['url'] = url
        self.url = url
        return self.data

    def setAuthor(self, name, iconURL, url) :
        self.data['author'] = { "name" : name, "iconURL" : iconURL, "url" : url }
        self.author = { name, iconURL, url }
        return self.data
    
    def setDescription(self, description) :
        self.data['description'] = description
        self.description = description
        return self.data

    def setThumbnail(self, url) :
        self.data['thumbnail'] = url
        self.thumbnail = url
        return self.data

    def setImage(self, url) :
        self.data['image'] = url
        self.image = url
        return self.data

    def setTimestamp(self) :
        self.data['timestamp'] = datetime.today().strftime('%Y-%m-%d %H:%M:%S')
        self.timestamp = datetime.today().strftime('%Y-%m-%d %H:%M:%S')
        return self.data

    def setFooter(self, text, iconURL) :
        self.data['footer'] = { "text": text, "iconURL": iconURL }
        self.footer =  { "text": text, "iconURL": iconURL }
        return self.data
    def getJson(self):
        return json.dumps(self.data)
    def __init__(self):
        self.data = {}
    def __str__(self):
        return json.dumps(self.data)


import json

from os import error
from stockly_python.client import Client
from stockly_python.messageEmbed import messageEmbed

myClient = Client()





@myClient.ee.on("open")
def on_open():
    print("Bot Connection Is Open")


@myClient.ee.on("command")
def command(data):
    myMessage = messageEmbed()
    myMessage.setColor('#0099ff')
    myMessage.setTitle('Some title')
    myMessage.setURL('https://discord.js.org/')
    myMessage.setAuthor('Some name', 'https://i.imgur.com/AfFp7pu.png', 'https://discord.js.org')
    myMessage.setDescription('Some description here')
    myMessage.setThumbnail('https://i.imgur.com/AfFp7pu.png')
    myMessage.setImage('https://i.imgur.com/AfFp7pu.png')
    myMessage.setTimestamp()    
    myMessage.setFooter('Some footer text here', 'https://i.imgur.com/AfFp7pu.png')
    print("Get Command From Mobile", data, type(myMessage))
    myClient.sendMessage(data['roomId'], 'hello i am from python')
    myClient.sendMessage(data['roomId'], myMessage)

    # myClient.sendSms(data['userId'], 'hello i am from python')
    # myClient.sendMessage(data['roomId'], 'hello i am from python')
    # myClient.sendMessage(data['roomId'], 'hello i am from python')

# @myClient.ee.on("setting")
# def setting(data):
#     print("setting", data)


@myClient.ee.on("error")
def setting(err):
    print("Bot get Socket error", err)


@myClient.ee.on("close")
def close():
    print("Bot Connection Is Close")

# myClient.sendMessage('qvtF5LdE01622750386728', 'hello i am from python')
# myClient.sendSms('MtZtrcTTz1622724929084', 'hello i am from python')
# myClient.sendPushNotification('qvtF5LdE01622750386728', 'hello i am from python')
# myClient.sendEmail('MtZtrcTTz1622724929084', 'test', '<h1>TEST</h1>')


myClient.login('N0f9qIa1640586773849a6805a7e989a', '237592481216856171')



from distutils.core import setup

setup(
    name='stockly_python',  # How you named your package folder (MyLib)
    packages=['stockly_python'],  # Chose the same as "name"
    version='0.15',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='testing',  # Give a short description about your library
    author='dev@stockly.us',  # Type in your name
    author_email='dev@stockly.us',  # Type in your E-Mail
    url='https://github.com/user/reponame',  # Provide either the link to your github or to your website
    download_url='https://gitlab.com/vzinjuvadia/stockly-python/-/archive/1.0.3/stockly-python-1.0.3.tar.gz',
    keywords=['BOT', 'STOCKLY', 'PYTHON'],  # Keywords that define your package best
    install_requires=[  # I get to this in a second
        'PyJWT',
        'pymitter',
        'requests',
        'certifi',
        'Flask'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',  # Again, pick a license
        'Programming Language :: Python :: 3',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    package_data={'stockly_python': ['config/*', ]}
)
